@@ -10,7 +10,7 @@ use App::Cmd::Setup -app;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.021'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -30,8 +30,8 @@ sub pinto {
     return $self->{pinto} ||= do {
         my %global_options = %{ $self->global_options() };
 
-        $global_options{repos}
-            or $self->usage_error('Must specify a repository server');
+        $global_options{repos}  ||= $ENV{PINTO_REPOSITORY}
+            || $self->usage_error('Must specify a repository server');
 
         my $pinto_class = $self->pinto_class();
         Class::Load::load_class($pinto_class);
@@ -59,7 +59,7 @@ App::Pinto::Remote - Command line driver for Pinto::Remote
 
 =head1 VERSION
 
-version 0.021
+version 0.026
 
 =head1 METHODS
 
